//////////////////////////////////////////////////////////////////////////
// file: lighthouse.pov
//
// title: Shoreline Sentry
//
// orign: Ground level centre of tower
//
// Copyright (c) 2004 Brett Dickson
//
//////////////////////////////////////////////////////////////////////////

#version 3.6;

#include "colors.inc"
#include "glass.inc"
#include "textures.inc"
#include "functions.inc"
#include "shapes.inc"
#include "skies.inc"
#include "stones1.inc"
#include "transforms.inc"
#include "woods.inc"

//Switches////////////////////////////////////////////////////////////////

#declare Complex_Concrete = 1;
#declare Complex_Rock = 1;
#declare Complex_Water = 1;
#declare Clounds = 1;
#declare Water = 1;
#declare Use_photons = 1;
#declare Use_radiosity = 1;

//Force the Radiosity and photon settings for final renders
#if(RenderPhase)
    #declare Use_radiosity = RenderPhase;
    #declare Use_photons = RenderPhase;
#end

//Global Settings/////////////////////////////////////////////////////////

global_settings {
    #if(Use_radiosity)
        radiosity { 
            error_bound 0.5
            nearest_count 7
            media on
        
            #switch(Use_radiosity)
                //Pass one
                #case(1)
                    count 20
                    pretrace_end 0.001
                    save_file "lighthouse.rad"
                #break
                //Pass two
                #case(2)
                    count 50
                    pretrace_end 0.002
                    load_file "lighthouse.rad"
                    always_sample off
                #break
            #end
        }
        ambient_light 0.1
    #else
        ambient_light 0.5
    #end
    max_trace_level 5

    #if(Use_photons)
        photons {
            count 200000
            autostop 0
            media on
            
            #switch(Use_photons)
                //Pass one
                #case(1)
                    save_file "lighthouse.ph"
                #break
                //Pass two
                #case(2)
                    load_file "lighthouse.ph"
                #break
            #end
        }
    #end
}

//A random offset to move textures and materials by
#declare TextureOffset = seed(26);

//Camera//////////////////////////////////////////////////////////////////
camera {
    location <0, -7.5, -65>
    look_at <12, 6, 5>
    
    rotate y*-30
}

//Lighting////////////////////////////////////////////////////////////////
light_source { 
    <1000, 750, -100>
    Wheat
} 

//Custom Finishes/////////////////////////////////////////////////////////

//Concrete finish for tower
#declare PaintedConcrete_White = texture {
    pigment { White }
    finish {
        ambient 0.5
        diffuse 1
        reflection 0.01
        specular 0.2
        roughness 0.6
    }
    
    #if(Complex_Concrete)
        normal {
            //bumps 0.15 scale 0.015
            function { f_noise3d(x*50, y*50, z*50) * 0.05 }
        }
    #end
}

//A modification of the painted concrete finish without the normal.  This 
//should be used on surfaces that generate their own concrete normal.
#declare PaintedConcrete_White_I = texture {
    pigment { White }
    finish {
        ambient 0.5
        diffuse 1
        reflection 0.01
        specular 0.2
        roughness 0.6
    }
}


//Red steel finish for roof
#declare PaintedSteel_Red = texture {
    pigment { Red }
    finish {
        ambient 0.5
        diffuse 0.5
        reflection 0.01
        specular 0.5
        roughness 0.2
    }

    normal {
        dents 0.15 scale 0.2
    }
}

//White steel finish for top of tower
#declare PaintedSteel_White = texture {
    pigment { White }

    finish {
        ambient 0.5
        diffuse 0.5
        reflection 0.01
        specular 0.5
        roughness 0.2
    }
    
    normal {
        //dents 0.25 scale 0.02
        dents 0.15 scale 0.2
    }
}

#declare PaintedSteel_Green = texture {
    pigment { GreenCopper }
    finish {
        ambient 0.5
        diffuse 0.5
        reflection 0.01
        specular 0.5
        roughness 0.2
    }

    normal {
        dents 0.15 scale 0.2
    }
}

//White Wood finish
#declare PaintedWood_White = texture {
    pigment { White }

    finish {
        ambient 0.5
        diffuse 0.5
        reflection 0.01
        specular 0.7
        roughness 0.2
    }
}

//Gray Concrete (unpainted)
#declare UnpaintedConcrete = texture {
    pigment { Gray75 }
    finish {
        ambient 0.5
        diffuse 1
        reflection 0.01
        specular 0
        roughness 0.7
    }
    
    normal {
        bumps 0.15 scale 0.02
    }
}

//Exteror brass finish
#declare Dull_Brass = texture {
    pigment { Brass*0.75 }
    finish {
        ambient 0.5
        diffuse 0.6
        reflection 0.6
        specular 0.7
        roughness 0.1
        brilliance 2
        metallic
    }
}

//The finish for all the standard window glass 
#declare WindowGlass = material {
    texture {
        pigment{ Col_Glass_Clear }
        finish{ F_Glass3 }
    
        //The glass in windows is a bit old as has warped
        normal {
            dents 0.4
            translate <2, 1, 0>
        }
        
        scale 15
    }
    
    interior {
        ior 1.5
    }
}

//A matt black finish for areas where we don't want any reflections
#declare MattBlack = texture {
    pigment{ Black }
    finish { Dull }
} 

//Macros//////////////////////////////////////////////////////////////////
//Repeat an object around part or all of a circle.
#macro CircleDuplicate(obj, step, maxRotate)
    #local rotation = 0;
    
    #if(maxRotate > 360)
        #local maxRotate = 360;
    #end
    
    union {
            #while (rotation < maxRotate)
                #local rotation = (rotation + step);
        
                object{ obj rotate y*rotation }
            #end
    }
#end

//Repeat an object along a path.
#macro LinearDuplicate(obj, step, length)
    #local cur_length = 0;
    
    union {
        #while (cur_length <= length)
            object{ obj translate x*cur_length }

            #local cur_length = (cur_length + step);
        #end
    }
#end

//Create a spiral staircase in the tower
#macro SpiralStairs()
    #local rotation = 0; 
    #local hight = 0;
    
    //Const vars
    #local maxHight = 20;
    #local rotationStep = 13;
    #local stepRise = 0.25;

    //single step
    #local stair = box {
        <-0.65, 0, 0>, <0.65, stepRise, -5>

        texture{ PaintedConcrete_White }
        //Rotate initial step to clear doorway
        rotate y*30
    }
    
    union {
            #while (hight < maxHight)
                object{ stair rotate y*rotation translate y*hight }
                
                #local rotation = (rotation + rotationStep);
                #local hight = (hight + stepRise);
            #end
    }
#end

//////////////////////////////////////////////////////////////////////////
// Base that lighthouse rests on.

#declare L_Base = union {
    cone {
        <0,0,0>, 5, <0,-0.5,0>, 7.5
    
        texture{ UnpaintedConcrete }    
    }

    cone {
        <0,-0.5,0>, 7.5, <0,-10,0>, 8.5
    
        texture{ UnpaintedConcrete }    
    }
}

//////////////////////////////////////////////////////////////////////////
// Tower

//////////////////////////////////////////////////////////////////////////
// Tower details

// Door
#declare L_TowerDoorDiff = union {
    box {
        <-1, -0.5, -5.5>, <1, 4, -3>
        
        texture{ PaintedConcrete_White }
    }


    difference {
        box {
            <-1.5, 4.1, -4.5>, <1.5, 6, -5>
            
            texture{ PaintedConcrete_White }
        }
        
        box {
            <-1.5, 4.1, -4.2>, <1.5, 6, -4.75>
            Rotate_Around_Trans(<0, 0, 30>, <-1.5, 4.1, -4>)

            texture{ PaintedConcrete_White }
        }

        box {
            <-1.5, 4.1, -4.2>, <1.5, 6, -4.75>
            Rotate_Around_Trans(<0, 0, -30>, <1.5, 4.1, -4>)

            texture{ PaintedConcrete_White }
        }
    }
}

#declare L_TowerDoor = union {
    //Door frame
    //inside = 4.49, Outside = 5.0
    difference {
        box {
            <-1.2, 0, -4.75>, <1.2, 4.1, -4.5>
            
            texture{ PaintedConcrete_White }
        }

        box {
            <-1, 0, -5>, <1, 4, -3>
            
            texture{ PaintedConcrete_White }
        }
    }
    
    intersection {
        difference {
            cone {
                <0, -0.05, 0>, 5.05      //Base
                <0, 20, 0>, 3.55         //Top
        
                texture{ PaintedConcrete_White }
            }
    
            cone {
                <0, -0.1, 0>, 4.49,     //Base
                <0, 20.1, 0>, 2.95      //Top
            
                texture{ PaintedConcrete_White }
            }
    
            box {
                <-20, 4, -20>, <20, 30, 20>
                
                texture{ PaintedConcrete_White }
            }
            
            box {
                <-1, 0, -5.5>, <1, 4, -2>
                
                texture{ PaintedConcrete_White }
            }
        }
        
        box {
            <-1.2, -0.05, -5.5>, <1.2, 4, -2>
            
            texture{ PaintedConcrete_White }
        }
    }

    //Door jam
    union {
        difference {
            box {
                <-1, 0, -4.70>, <1, 4, -4.60>
                
                texture{ PaintedWood_White }
            }
    
            box {
                <-0.95, 0, -5>, <0.95, 3.95, -3>
                
                texture{ PaintedWood_White }
            }
            
            //Cutout for door striker
            box {
                <-0.9, 2.45, -4.64>, <-0.955, 2.55, -4.61>
                
                texture { PaintedWood_White }
            }
            
            box {
                <-0.9, 2.473, -4.632>, <-0.985, 2.527, -4.613>
                
                texture{ PaintedWood_White }
            }
            
            box {
                <-0.9, 2.476, -4.64>, <-0.955, 2.524, -4.55>
                
                texture { PaintedWood_White }
            }
        }
        
        difference {
            box {
                <-1, 0, -4.70>, <1, 4, -4.66>
                
                texture{ PaintedWood_White }
            }
    
            box {
                <-0.92, 0, -5>, <0.92, 3.92, -3>
                
                texture{ PaintedWood_White }
            }
        }
    }
    
    //Door striker (made of brass)
    difference {
        box {
            <-0.95, 2.45, -4.64>, <-0.955, 2.55, -4.61>
            
            texture { Dull_Brass }
        }
        
        box {
            <-0.9, 2.475, -4.635>, <-1, 2.525, -4.615>
            
            texture { Dull_Brass }
        }

        //Slots for screws
        box {
            <-0.9, 2.54, -4.622>, <-0.951, 2.541, -4.628>

            Rotate_Around_Trans(<65, 0, 0>, <-0.951, 2.541, -4.625>)
            texture { Dull_Brass }
        }

        box {
            <-0.9, 2.46, -4.622>, <-0.951, 2.461, -4.628>

            Rotate_Around_Trans(<34, 0, 0>, <-0.951, 2.461, -4.625>)
            texture { Dull_Brass }
        }
    }

    intersection {
        cylinder {
            <-0.98, 2.476, -4.61>, <-0.98, 2.524, -4.61>, 0.03
            
            texture { Dull_Brass }
        }
        
        box {
            <-0.95, 2.4, -4.61>, <-0.9525, 2.6, -4.59>
            
            texture { Dull_Brass }
        }
    }
    
    //Stuff above the door
    difference {
        box {
            <-1.5, 4.1, -4.2>, <1.5, 6, -4.75>
            
            texture{ PaintedConcrete_White }
        }
        
        box {
            <-1.5, 4.1, -4.2>, <1.5, 6, -5>
            Rotate_Around_Trans(<0, 0, 30>, <-1.5, 4.1, -4>)
            
            texture{ PaintedConcrete_White }
        }

        box {
            <-1.5, 4.1, -4.2>, <1.5, 6, -5>
            Rotate_Around_Trans(<0, 0, -30>, <1.5, 4.1, -4>)
            
            texture{ PaintedConcrete_White }
        }
    }
    
    box {
        <-1.5, 4.1, -4.2>, <1.5, 4.2, -4.85>

        texture{ PaintedConcrete_White }
    }
    box {
        <-1.5, 4.1, -4.2>, <0.29, 4.2, -4.85>
        Rotate_Around_Trans(<0, 0, 30>, <-1.5, 4.1, -4>)

        texture{ PaintedConcrete_White }
    }
    box {
        <-0.29, 4.1, -4.2>, <1.5, 4.2, -4.85>
        Rotate_Around_Trans(<0, 0, -30>, <1.5, 4.1, -4>)

        texture{ PaintedConcrete_White }
    }
    
    text {
        ttf "arial.ttf", "1872", 0.2, 0
        
        scale <0.4, 0.4, 1>
        texture{ PaintedConcrete_White }
        translate <-(Text_Width("arial.ttf", "1872", 0.4, 0)/2), 4.3, -4.77>
    }
}

// Window (duplicate as needed up tower)
#declare L_TowerWindowDiffInner = box {
    <-0.25, 2.5, -5.5>, <0.25, 3.5, 0>

    texture{ PaintedConcrete_White }
}

#declare L_TowerWindowDiffOuter = difference {
    union {
        box {
            <-0.4, 2.49, 0>, <0.4, 3, -1.5> 
            
            Rotate_Around_Trans(<-15, 0, 0>, <0, 2.5, 0>)
            texture{ PaintedConcrete_White }
        }
    
        box {
            <-0.4, 3, -0.05>, <0.4, 3.51, -1.5>
            
            Rotate_Around_Trans(<15, 0, 0>, <0, 3.5, -0.05>) 
            texture{ PaintedConcrete_White }        
        }
    
        box {
            <-0.249, 2.3, -0.05>, <0, 3.7, -1.5>
            
            Rotate_Around_Trans(<0, 15, 0>, <-0.25, 3.5, -0.05>) 
            texture{ PaintedConcrete_White }
        }
    
        box {
            <0, 2.3, -0.05>, <0.251, 3.7, -1.5>
            
            Rotate_Around_Trans(<0, -15, 0>, <0.25, 3.5, -0.05>) 
            texture{ PaintedConcrete_White }        
        }
    }

    union {
        box {
            <-0.4, 2, 0>, <0.4, 2.5, -1.5> 
            
            Rotate_Around_Trans(<-15, 0, 0>, <0, 2.5, 0>)
            texture{ PaintedConcrete_White }
        }
        
        box {
            <-0.4, 3.5, -0.05>, <0.4, 4, -1.5>
            
            Rotate_Around_Trans(<15, 0, 0>, <0, 3.5, -0.05>) 
            texture{ PaintedConcrete_White }        
        }
    
        box {
            <-1, 2, -0.05>, <-0.25, 4, -1.5>
            
            Rotate_Around_Trans(<0, 15, 0>, <-0.25, 3.5, -0.05>)
            texture{ PaintedConcrete_White }
        }

        box {
            <0.25, 2, -0.05>, <1, 4, -1.5>
            
            Rotate_Around_Trans(<0, -15, 0>, <0.25, 3.5, -0.05>) 
            texture{ PaintedConcrete_White }        
        }
    }
}

//Create version of the window diff with bits that are specific to the 
//diameter of the tower at each window hight
#declare L_TowerWindowDiff1 = union {
    object { L_TowerWindowDiffInner }
    object { L_TowerWindowDiffOuter translate z*-4.5 }
}


#declare L_TowerWindowDiff2 = union {
    object { L_TowerWindowDiffInner }
    object { L_TowerWindowDiffOuter translate z*-3.97 }
}

#declare L_TowerWindowDiff3 = union {
    object { L_TowerWindowDiffInner }
    object { L_TowerWindowDiffOuter translate z*-3.44 }

}

#declare L_TowerWindow = union {
    //Window frame
    box { //Left upright
        <-0.25, 2.49, 0.01>, <-0.20, 3.51, -0.03> 
        texture { PaintedSteel_White }
    }
    box { //Right upright
        <0.20, 2.49, 0.01>, <0.25, 3.51, -0.03> 
        texture { PaintedSteel_White }
    }
    box { //Bottom horizontal
        <-0.25, 2.49, 0.01>, <0.25, 2.55, -0.03> 
        texture { PaintedSteel_White }
    }
    box { //Top horizontal 
        <-0.25, 3.45, 0.01>, <0.25, 3.51, -0.03> 
        texture { PaintedSteel_White }
    }

    //Cross hairs though middle of window
    box { //Vertical
        <-0.01, 2.5, 0.01>, <0.01, 3.5, -0.02> 
        texture { PaintedSteel_White }
    }
    box { //Horizontal
        <-0.25, 2.99, 0.01>, <0.25, 3.01, -0.02> 
        texture { PaintedSteel_White }
    }
    //Small bump in middle where two crosses meet
    box { 
        <-0.015, 2.99, 0.01>, <0.015, 3.01, -0.022> 
        texture { PaintedSteel_White }
    }
    
    //Pane of glass in window
    box {
        <-0.25, 2.5, 0>, <0.25, 3.5, -0.01>

        hollow
        material { WindowGlass }
        
        photons {
            target
            refraction on
            reflection on
            collect off
        }
    }
}

#declare L_TowerWindows = union {
    union {
        object{ L_TowerWindow  translate z*-4.5}
        object{ L_TowerWindow  translate z*-3.97 translate y*7}
        object{ L_TowerWindow  translate z*-3.44 translate y*14}
        
        rotate y*-45
    }
    
    union {
        object{ L_TowerWindow  translate z*-4.5}
        object{ L_TowerWindow  translate z*-3.97 translate y*7}
        object{ L_TowerWindow  translate z*-3.44 translate y*14}
        
        rotate y*135
    }
}

#declare L_PlatformTrim1 = difference {
    box {
        <0, 0, -0.2>, <1.35, 2, 0.2>
    
        texture{ PaintedConcrete_White }
    }

    cylinder {
        <1.3, 0, -1>, <1.3, 0, 1>, 0.65

        scale <1, 2, 1>

        texture{ PaintedConcrete_White }
    }
    
    translate<3, 18.5, 0>
}

#declare L_TowerStairs = intersection { 
    SpiralStairs() 

    cone {
        <0, -0.1, 0>, 4.49,     //Base
        <0, 20.1, 0>, 2.95      //Top
    
        texture{ PaintedConcrete_White }
    }
}

//Tower itself
#declare L_Tower = union {
    difference {
        union {
            isosurface {
                function { 
                    sqrt(pow(x/((y * (-1.5/20)) + 5), 2) + pow(z/((y * (-1.5/20)) + 5), 2)) - 1 
                    #if(Complex_Concrete)
                        - f_noise3d(x*50, y*50, z*50) * 0.0005
                    #end
                }

                contained_by { box { <-5.1, 0, -5.1>, <5.1, 20, 5.1> } }
                max_gradient 0.4
                
                texture{ PaintedConcrete_White_I }
            }
            
            object{ CircleDuplicate(L_PlatformTrim1, 12, 360) }
        }

        cone {
            <0, -0.1, 0>, 4.49,     //Base
            <0, 20.1, 0>, 2.95      //Top
        
            texture{ PaintedConcrete_White }
        }

        //Diff for Doorway
        object{ L_TowerDoorDiff }
        
        //Diff for Windows
        union {
            object{ L_TowerWindowDiff1 }
            object{ L_TowerWindowDiff2 translate y*7 }
            object{ L_TowerWindowDiff3 translate y*14 }
            
            rotate y*-45
        }
    
        //More windows (on other side of tower)
        union {
            object{ L_TowerWindowDiff1 }
            object{ L_TowerWindowDiff2 translate y*7 }
            object{ L_TowerWindowDiff3 translate y*14 }
            
            rotate y*135
        }
    }
    
    object{ L_TowerWindows }
    object{ L_TowerDoor }
}

//Centre column in tower (for clockwork and staircase)
#declare L_TowerCore = cylinder {
    <0, 0, 0>, <0, 21, 0>, 1

    texture{ PaintedConcrete_White }
}

#declare L_TowerInt = union {
    object{ L_TowerCore }
    object{ L_TowerStairs }
}

#declare L_RailingPost1 = cylinder {
    <0, 20.5, 4.4>, <0, 22.5, 4.4>, 0.04

    texture{ PaintedSteel_White }    
}

//Walkway at top of main tower
#declare L_Platform = union {
    //Concrete base to platform    
    difference {
        isosurface {
            function { 
                sqrt(pow(x/4.5,2) + pow(z/4.5,2)) - 1 
                #if(Complex_Concrete)
                    - f_noise3d(x*50, y*50, z*50) * 0.0005
                #end
            }
            
            contained_by { box { <-5, 20, -5>, <5, 20.5, 5> } }
            max_gradient 0.4
            
            texture{ PaintedConcrete_White_I }
        }

        cylinder {
            <0, 19, 0>, <0, 21.5, 0>, 2.89

            texture{ PaintedConcrete_White }
        }
    }

    //Railing
    torus {
        4.4, 0.075

        texture{ PaintedSteel_White }
    
        translate y*22.5
    }

    object{ CircleDuplicate(L_RailingPost1, 5, 360) }
}
               
//////////////////////////////////////////////////////////////////////////
// Top

#declare L_FrameHandle = union {
    //Top courner of handle
    union {
        difference {
            torus {
                0.04, 0.02

                texture{ PaintedSteel_White }
    
                rotate x*90
            }

            box {
                <-2, 2, -2>, <0, -2, 2>

                texture{ PaintedSteel_White }
            }

            box {
                <-2, 0, -2>, <2, -2, 2>

                texture{ PaintedSteel_White }
            }
        }
    
        cylinder {
            <0, 0.04, 0>, <-0.05, 0.04, 0>, 0.02

            texture{ PaintedSteel_White }
        }

        translate y*0.06
    }

    //Face of handle
    cylinder {
        <0.04, -0.06, 0>, <0.04, 0.06, 0>, 0.02

        texture{ PaintedSteel_White }
    }

    //Bottom courner of handle
    union {
        difference {
            torus {
            0.04, 0.02

                texture{ PaintedSteel_White }
    
                rotate x*90
            }

            box {
                <-2, 2, -2>, <0, -2, 2>

                texture{ PaintedSteel_White }
            }

            box {
                <-2, 0, -2>, <2, 2, 2>

                texture{ PaintedSteel_White }
            }
        }

        cylinder {
            <0, -0.04, 0>, <-0.05, -0.04, 0>, 0.02

            texture{ PaintedSteel_White }
        }

        translate y*-0.06
    }

    rotate y*90
}

//Windows and light room structure
#declare L_TopFrame1 = union {
    //Frame courner
    cylinder {
        <0, 20, -3>, <0, 27, -3>, 0.05

        texture{ PaintedSteel_White }
        rotate y*15
    }
    
    object{ L_FrameHandle translate<0, 23.6, -3.06> rotate y*15}
    object{ L_FrameHandle translate<0, 25, -3.06> rotate y*15}
    object{ L_FrameHandle translate<0, 26.4, -3.06> rotate y*15}
    
    // Gutter
    difference {
        union {
            cylinder {
                <-1, 27.1, 3.15>, <1, 27.1, 3.15>, 0.25
    
                texture{ PaintedSteel_White }
            }
            
            cylinder {
                <-1, 27.1, 3.15>, <-0.75, 27.1, 3.15>, 0.26
    
                texture{ PaintedSteel_White }
            }
            
            cylinder {
                <0.75, 27.1, 3.15>, <1, 27.1, 3.15>, 0.26
    
                texture{ PaintedSteel_White }
            }
        }

        cylinder {
            <-2, 27.1, 3.15>, <2, 27.1, 3.15>, 0.245

            texture{ PaintedSteel_White }
        }

        box {
            <-2, 27.1, 2>, <2, 28, 4>

            texture{ PaintedSteel_White }
        }

        box {
            <0, 26, 0>, <-2, 28, 4>

            texture{ PaintedSteel_White }
            rotate y*-15
        }

        box {
            <0, 26, 0>, <2, 28, 4>

            texture{ PaintedSteel_White }
            rotate y*15
        }
    }
}

//Glass for the windows
#declare L_WindowGlass1 = union {
    box {
        <-0.78, 23, 2.89>, <0.78, 27, 2.9>

        hollow        
        material { WindowGlass }
        
        photons {
            target
            refraction on
            reflection on
            collect off
        }
    }

    cylinder {
        <-0.78, 23, 2.89>, <0.78, 23, 2.9>, 0.05

        texture{ PaintedSteel_White }
    }
    
    cylinder {
        <-0.78, 24.3, 2.89>, <0.78, 24.3, 2.9>, 0.05

        texture{ PaintedSteel_White }
    }

    cylinder {
        <-0.78, 25.7, 2.89>, <0.78, 25.7, 2.9>, 0.05

        texture{ PaintedSteel_White }
    }

    cylinder {
        <-0.78, 27, 2.89>, <0.78, 27, 2.9>, 0.05

        texture{ PaintedSteel_White }
    }

    rotate y*-120
}

//Door from light room outside
#declare L_TopDoor = union {
    //Door frame 
    cylinder {
        <-0.65, 20.6, 0>, <-0.65, 24.6, 0>, 0.05
        texture{ PaintedSteel_White }
    }

    cylinder {
        <0.65, 20.6, 0>, <0.65, 24.6, 0>, 0.05
        texture{ PaintedSteel_White }
    }

    cylinder {
        <-0.65, 20.6, 0>, <0.65, 20.6, 0>, 0.05
        texture{ PaintedSteel_White }
    }

    //Weather flashing along top of door    
    box {
        <-0.7, 0, 0>, <0.7, 0.05, -0.25>

        texture{ PaintedSteel_White }

        //Remember we are rotating around <0, 0, 0>
        rotate x*-15
        translate y*24.6
    }
    
    //Door handle
    union {
        difference {
            torus {
                0.04, 0.02

                texture{ Dull_Brass }
            }

            box {
                <-2, -2, 0>, <2, 2, 2>

                texture{ Dull_Brass }
            }

            box {
                <0, -2, -2>, <2, 2, 2>

                texture{ Dull_Brass }
            }
        }

        //Section of handle pointing into door
        cylinder {
            <-0.04, 0, 0>, <-0.04, 0, 0.05>, 0.02

            texture{ Dull_Brass }
        }

        //Grab section of handle        
        cylinder {
            <0, 0, -0.04>, <0.1, 0, -0.04>, 0.02

            texture{ Dull_Brass }
        }
        
        translate<-0.5, 23.1, 0>
    }


    //Move door to correct location on side of light room
    translate z*-2.9
}

//Base of light room
#declare L_TopCladdingBase1 = union {
    box {
        <-0.78, 20, 2.89>, <0.78, 23, 2.9>

        texture{ PaintedSteel_White }
    }

    box {
        <-0.78, 20, 2.79>, <0.78, 23, 2.8>

        texture{ T_Wood14 }
    }
}

#declare L_TopCladdingBack1 = union {
    box {
        <-0.78, 22.9, 2.89>, <0.78, 27, 2.9>

        texture{ PaintedSteel_White }
    }

    box {
        <-0.78, 22.9, 2.79>, <0.78, 27, 2.8>

        texture{ T_Wood14 }
    }
    
    rotate y*120
}

// Roof
#declare L_RoofSection = union {
    intersection{
        difference {
            cylinder {
                <-3, 27, 0>, <3, 27, 0>, 2.9

                texture{ PaintedSteel_Red }
            }

            cylinder {
                <-5, 27, 0>, <5, 27, 0>, 2.89

                texture{ MattBlack }
            }

            box {
                <-10, 20, -10>, <10, 27, 10>

                texture{ PaintedSteel_Red }        
            }
        }

        cylinder {
            <-3, 27, 0>, <3, 27, 0>, 2.9

            texture{ PaintedSteel_Red }
            rotate y*30
        }

        cylinder {
            <-3, 27, 0>, <3, 27, 0>, 2.9

            texture{ PaintedSteel_Red }
            rotate y*-30
        }
        
        scale 1.0025
    }

    //Beading between roof panels
    difference {
        torus {
            3, 0.05
        
            rotate z*90
            rotate y*15
            translate <0, 27, 0>

            texture{ PaintedSteel_Red }
        }

        box {
            <-10, 20, -10>, <10, 27, 10>

            texture{ PaintedSteel_Red }        
        }
    }
}

#declare L_windVaneFeather = union {
    cylinder {
        <0, 0, 0>, <-0.15, 0.25, 0>, 0.04
        texture{ PaintedSteel_Red }
    }

    sphere {
        <-0.15, 0.25, 0>, 0.04
        texture{ PaintedSteel_Red }
    }
}

#declare L_WindVaneTailPart = union {
    object{ L_windVaneFeather translate x*-0.6 }
    object{ L_windVaneFeather translate x*-0.65 }
    object{ L_windVaneFeather translate x*-0.7 }
    object{ L_windVaneFeather translate x*-0.75 }
    object{ L_windVaneFeather translate x*-0.8 }
    object{ L_windVaneFeather translate x*-0.85 }
    object{ L_windVaneFeather translate x*-0.9 }
    object{ L_windVaneFeather translate x*-0.95 }
    object{ L_windVaneFeather translate x*-1 }
}

#declare L_WindVaneTail = union {
    object{ L_WindVaneTailPart }
    object{ L_WindVaneTailPart rotate x*180 }

    translate y*32
}

#declare L_WindVane = union {
    cylinder {
        <0, 29, 0>, <0, 31, 0>, 0.4
        texture{ PaintedSteel_Red }
    }

    //Windvane
    union {   
        //Stem
        cylinder {
            <0, 31, 0>, <0, 32, 0>, 0.05
            texture{ PaintedSteel_Red }
         }

        //Rod at top of stem
        sphere {
            <0, 32, 0>, 0.1
            texture{ PaintedSteel_Red }
        }

        //horizontal rod    
        cylinder {
            <-1, 32, 0>, <0.9, 32, 0>, 0.05
            texture{ PaintedSteel_Red }
        }
        
        sphere {
            <-1, 32, 0>, 0.05
            texture{ PaintedSteel_Red }
        }

        //Arrow head
        cone {
            <0.75, 32, 0>, 0.175, <1.25, 32, 0>, 0
            texture{ PaintedSteel_Red }            
        }

        //Tail
        object{ L_WindVaneTail }
        
        //Rotate the wind vane as desired...
        rotate y*-35
    }

    //Vent sphere
    difference {    
        sphere {
            <0, 31, 0>, 0.6

            texture{ PaintedSteel_Red }
        }

        sphere {
            <0, 31, 0>, 0.59

            texture{ PaintedSteel_Red }
        }

        cylinder {
            <0, 29.8, 0>, <0, 31, 0>, 0.45
            texture{ PaintedSteel_Red }
        }
    }
    
    rotate y*-10
}

// Ceilling
#declare L_Ceilling1 = difference {
    box {
        <-2, 27, 0>, <2, 27.05, 2.8>

        texture{ T_Wood14 }
    }

    box {
        <0, 26, 0>, <-2, 28, 4>

        texture{ T_Wood14 }
        rotate y*-15
    }

    box {
        <0, 26, 0>, <2, 28, 4>

        texture{ T_Wood14 }
        rotate y*15
    }
}

#declare L_Roof = union {
    object{ CircleDuplicate(L_Ceilling1, 30, 360) }
    object{ CircleDuplicate(L_RoofSection, 30, 180) }

    object{ L_WindVane }
}

#declare L_Top = union {
    object{ CircleDuplicate(L_TopFrame1, 30, 360) }
    object{ CircleDuplicate(L_WindowGlass1, 30, 240) }

    object{ CircleDuplicate(L_TopCladdingBase1, 30, 360) }
    object{ CircleDuplicate(L_TopCladdingBack1, 30, 120) }

    object{ L_TopDoor }

    object{ L_Roof }
}

//////////////////////////////////////////////////////////////////////////
// Rock outcrop for lighthouse
#declare S_Rock_Base = isosurface {
    //Make up a rock like surface for the lighthouse to sit on.
    function { f_rounded_box((x*30)/(y-40), y, (z*30)/(y-40), 1.5, 10, 10, 15)
        #if(Complex_Rock)
             -(f_agate(x/2, y/2, z/2)*0.25)
             -(f_noise3d(x/4, y/5, z/2)*5) 
        #end
    }

    contained_by { box { <-25, -20, -30>, <25, 20, 30> } }  
    
    #if(Complex_Rock)
        max_gradient 4.9
    #else
        max_gradient 3
    #end
}

//Need to add a tide mark to the rock just above the level of the water
#declare S_TideMark = isosurface {
    function {
        y 
        #if(Complex_Rock)
            - f_noise3d(x/3.75, y, z/3.75)
        #end
    }

    contained_by { box { <-25, -20, -30>, <25, 2, 30> } }  
    
    #if(Complex_Rock)
        max_gradient 1.6
    #else
        max_gradient 1
    #end

    translate y*7.25
}

//Rock above water line
#declare S_Rock_Above = difference {
    object{ S_Rock_Base }
    object{ S_TideMark }
    
    texture { T_Grnt9 }
}

//Rock below water line
#declare S_Rock_Below = intersection {
    object{ S_Rock_Base }
    object{ S_TideMark }

    texture { T_Grnt15
        finish{ 
            reflection {
                0.0, 1.0
                fresnel on
            }
            
            specular 0.6
            roughness 0.03
        }
    }
}

#declare S_Rock = union {
    object{ S_Rock_Above }
    object{ S_Rock_Below }
    
    translate y*-15
}

//Sea surface
#declare S_SeaSurface = isosurface {
    function {
        y 
        #if(Complex_Water)
            - f_noise3d(x/6.5, y, z/6.5)
            - f_ridged_mf(x/2, y/2000, z/2, 0.2, 3, 7, 0.85, 0.6, 2) / 6
        #end
    }
    
    contained_by { box { <-1000, -16.5, -1000>, <1000, 1, 1000> } }
    
    #if(Complex_Water)
        max_gradient 2.2
    #else
        max_gradient 0.5
    #end
    
    texture {
        pigment {
            color Clear
        }

        finish {
            ambient 0.0
            diffuse 0.0

            reflection {
                0.0, 1.0
                fresnel on
            }

            specular 0.4
            roughness 0.03
        }
    }
    
    photons {
        target
        refraction on
        reflection on
        collect off
    }
    
    interior { ior 1.3 }
    hollow

    translate y*-8.5
}

//Sea bed
#declare S_SeaBed = plane { 
    y, -25
    pigment{ LightWood }

    #if(Complex_Water)
        normal {
            bumps 0.5
            scale 5
        }
    #end
}

#declare S_Sea = union {
    object{ S_SeaSurface }
    object{ S_SeaBed }    
}

#declare S_SkyBackground = sphere{
    <0,0,0>,1 
    hollow 
    
    texture{
        pigment {
            gradient <0,1,0>
            color_map{
                  [0.0 color rgb<1,1,1> ]
                  [0.8 color rgb<0.1,0.6,0.9> ]
                  [1.0 color rgb<0.1,0.6,0.9> ]
            }
        }

        finish {
            ambient 1 
            diffuse 0
        } 
    }
    
    scale 10000
}

sky_sphere {
    pigment {
        gradient y
        color_map {
            [ 0.5  color SummerSky ]
            [ 1.0  color CornflowerBlue ]
        }
        scale 2
        translate -1
    }
}

#declare S_SkyClouds = plane {
    y, 1500
    hollow
    texture{ T_Cloud3 scale 2500}
}

#declare S_Sky = object {
    #if(Clounds)
        object{ S_SkyClouds }
    #end
}

fog {
    distance 5000 
    color Wheat

    fog_type 2
    fog_offset 200
    fog_alt 5
}

//////////////////////////////////////////////////////////////////////////
//Sea Gull
#declare S_Bird = box {
    <0, 0, 0>, <1, 1, 0.0001>
    
    pigment {
        image_map {
            gif "bird.gif"

            map_type 0 
            interpolate 2
            once
            
            transmit 224, 1
        }        
    }

    //Scale to get the image ratio correct
    scale <1.55, 1, 1>
    
    //Now uniformly scale the entire image to the desired size
    scale 1.5
}

//////////////////////////////////////////////////////////////////////////
//Ship
#declare Ship_Portal = union {
    cylinder {
        <0, 0, 0>, <0, 0, 0.1>, 1
        
        hollow
        material { WindowGlass }
        
        photons {
            target
            refraction on
            reflection on
            collect off
        }
    }
    
    difference {
        cylinder {
            <0, 0, -0.05>, <0, 0, 0>, 1.25
            
            texture { Dull_Brass }
        }
        
        cylinder {
            <0, 0, -1>, <0, 0, 1>, 1
            
            texture { Dull_Brass }
        }
    }
}

#declare Ship_BridgeWindow = union {
    //Curved glass pane
    intersection {
        difference {
            cylinder {
                <0, 10, 0>, <0, 35, 0>, 10

                hollow
                material { WindowGlass }
                
                photons {
                    target
                    refraction on
                    reflection on
                    collect off
                }
            }
            
            cylinder {
                <-25, 10, 0>, <-25, 35, 0>, 9.9

                hollow
                material { WindowGlass }
                
                photons {
                    target
                    refraction on
                    reflection on
                    collect off
                }
            }
        }
        
        box { 
            <0, 31, -1>, <-20, 34, 1> 
            
            hollow
            material { WindowGlass }
            
            photons {
                target
                refraction on
                reflection on
                collect off
            }
        }
    }
    
    //Brass frame
    intersection {
        difference {
            cylinder {
                <0, 10, 0>, <0, 35, 0>, 10.1

                texture { Dull_Brass }
            }
            
            cylinder {
                <0, 10, 0>, <0, 35, 0>, 10

                texture { Dull_Brass }
            }
        }
        
        difference {
            box { 
                <0, 30.75, -1.25>, <-20, 34.25, 1.25> 
                
                texture { Dull_Brass }
            }

            box { 
                <0, 31, -1>, <-20, 34, 1> 
                
                texture { Dull_Brass }
            }
        }
    }
}

#declare Ship_Lifeboat_Profile = difference {
    union {
        sphere {
            <-5, 3, 0>, 5 
            texture { PaintedSteel_White }
        }
        
        cylinder { 
            <-5, 3, 0>, <5, 3, 0>, 5
            texture { PaintedSteel_White }
        }    
        
        sphere {
            <5, 3, 0>, 5
            texture { PaintedSteel_White }
        }
    }
    
    box {
        <-10, 3, -10>, <10, 10, 10>
        texture { PaintedSteel_White }
    }
    
    union {
        sphere {
            <-5, 3, 0>, 4.8
            texture { PaintedSteel_White }
        }
        
        cylinder { 
            <-5, 3, 0>, <5, 3, 0>, 4.8
            texture { PaintedSteel_White }
        }    
        
        sphere {
            <5, 3, 0>, 4.8
            texture { PaintedSteel_White }
        }
    }
    
    scale z*2
}

#declare Ship_Lifeboat = union {
    difference {
        object { Ship_Lifeboat_Profile }
        
        box {
            <-10, -10, 7>, <10, 10, -10>
        }
        
        translate z*-7
    }
    
    difference {
        object { Ship_Lifeboat_Profile }

        box {
            <-10, -10, -7>, <10, 10, 10>
        }
        
        translate z*7
    }
}

//Ship
#declare Ship = union {
    //Hull
    difference {
        blob {
            sphere { 
                0, 30, 1
                texture { PaintedSteel_Green }
                
                scale x*5
                scale y*4
            }
            
            cylinder {
                <0, 20, 0>, <0, -20, 0>, 30, 1
                texture { PaintedSteel_Green }
    
                rotate z*5
                scale x*5
            }

            cylinder {
                <0, 20, 0>, <0, -20, 0>, 30, 1
                texture { PaintedSteel_Green }
    
                scale x*5
            }
            
            cylinder {
                <85, -25, -20>, <85, -25, 20>, 30, -1
                texture { PaintedSteel_Green }
            }
        }
        
        cylinder {
            <4, 25, -100>, <4, 25, 100>, 20
            
            scale x*7
            texture { PaintedSteel_Green }
        }
    }

    //Lower level of superstructure
    difference {
        union {
            cylinder {
                <-40, 5, 0>, <-40, 15, 0>, 15
                texture { PaintedSteel_White }
            }

            box {
                <-40, 5, -15>, <30, 15, 15>
                texture { PaintedSteel_White }
            }
        }

        union {
            cylinder {
                <-40, 5, 0>, <-40, 14.9, 0>, 14.9
                texture { PaintedSteel_White }
            }

            box {
                <-40, 5, -14.9>, <29.9, 14.9, 14.9>
                texture { PaintedSteel_White }
            }
        }
    
        object { LinearDuplicate(cylinder {<-36, 12, -20>, <-36, 12, 20>, 1 texture { PaintedSteel_White } }, 10, 65) }
    }
    
    object { LinearDuplicate(Ship_Portal, 10, 65) translate <-36, 12, -15> }

    //second level of superstructure
    difference {
        box {
            <-25, 15, -10>, <0, 25, 10>
            texture { PaintedSteel_White }
        }

        box {
            <-24.9, 15.1, -9.9>, <-0.1, 24.9, 9.9>
            texture { PaintedSteel_White }
        }

        object { LinearDuplicate(cylinder {<-25, 22, -20>, <-25, 22, 20>, 1 texture { PaintedSteel_White } }, 10, 25) }
    }
    
    object { LinearDuplicate(Ship_Portal, 10, 25) translate <-25, 22, -10> }

    //Steps between levels
    box {
        <30, 15, -14>, <45, 14, -10>
    
        texture { PaintedSteel_White }
        Rotate_Around_Trans(<0, 0, -55>, <30, 15, -14>)
    }

    box {
        <30, 15, 14>, <45, 14, 10>
    
        texture { PaintedSteel_White }
        Rotate_Around_Trans(<0, 0, -55>, <30, 15, 14>)
    }

    //Bridge
    difference {
        union {
            cylinder {
                <-25, 10, 0>, <-25, 35, 0>, 10
                texture { PaintedSteel_White }
            }
            
            box {
                <-25, 25, -10>, <-15, 35, 10>
                texture { PaintedSteel_White }
            }
            
            //Door frame
            cylinder {
                <-25, 25, -10>, <-25, 34, -10>, 0.25
                texture { PaintedSteel_White }
            }
            
            cylinder {
                <-25, 34, -10>, <-22, 34, -10>, 0.25
                texture { PaintedSteel_White }
            }
            
            cylinder {
                <-22, 25, -10>, <-22, 34, -10>, 0.25
                texture { PaintedSteel_White }
            }
        }
        
        union {
            cylinder {
                <-25, 10, 0>, <-25, 34.9, 0>, 9.9
                texture { PaintedSteel_White }
            }

            box {
                <-25, 25.1, -9.9>, <-15, 34.9, 9.9>
                texture { PaintedSteel_White }
            }
        }
        
        //holes for bridge Windows
        object { 
            CircleDuplicate(box { <0, 31, -1>, <-20, 34, 1> texture { PaintedSteel_White } rotate y*-80 }, 20, 160)
            translate x*-25
        }
        
        cylinder {<-18, 32, -20>, <-18, 32, 20>, 1 texture { PaintedSteel_White } }
    }

    //Bridge windows
    object {
        CircleDuplicate(Ship_BridgeWindow, 20, 160)

        rotate y*-80        
        translate x*-25
    }
    object { Ship_Portal translate <-18, 32, -10> }
    
    //Ship's name
    box {
        <-25, 26, -14>, <-16, 28, -14.5>
        texture { T_Wood7 }
    }
    text {
        ttf "arial.ttf", "RELIANT", 1, 0
        
        scale <1.5, 1.5, 1>
        texture{ Dull_Brass }
        translate <-(Text_Width("arial.ttf", "RELIANT", 0.4, 0)/2) - 23, 26.5, -14.6>
    }
    
    //shade above bridge windows
    difference {
        cylinder {
            <-25, 34.9, 0>, <-25, 35, 0>, 11
            texture { PaintedSteel_White }
        }
        
        box {
            <-25, 30, -15>, <0, 40, 15>

            Rotate_Around_Trans(<0, 20, 0>, <-25, 30, 0>)
            texture { PaintedSteel_White }
        }
        
        box {
            <-25, 30, -15>, <0, 40, 15>

            Rotate_Around_Trans(<0, -20, 0>, <-25, 30, 0>)
            texture { PaintedSteel_White }
        }
    }

    difference {
        box {
            <-27, 24.9, -14>, <-10, 30, 14>
            texture { PaintedSteel_White }
        }

        box {
            <-26.9, 25, -13.9>, <-10.1, 35, 13.9>
            texture { PaintedSteel_White }
        }

        box {
            <-30, 25, -10>, <0, 35, 10>
            texture { PaintedSteel_White }
        }
    }

    //Railling (lower level behind bridge)
    object { LinearDuplicate(cylinder{<-40, 15, -15>, <-40, 20, -15>, 0.15 texture { PaintedSteel_White }}, 5, 60) }
    object { CircleDuplicate(cylinder{<0, 15, -15>, <0, 20, -15>, 0.15 texture { PaintedSteel_White }}, 15, 179) translate x*-40 }
    object { LinearDuplicate(cylinder{<-40, 15, 15>, <-40, 20, 15>, 0.15 texture { PaintedSteel_White }}, 5, 60) }

    cylinder{<-40, 17.5, -15>, <20, 17.5, -15>, 0.15 texture { PaintedSteel_White }}
    cylinder{<-40, 17.5, 15>, <20, 17.5, 15>, 0.15 texture { PaintedSteel_White }}

    cylinder {<-40, 20, -15>, <20, 20, -15>, 0.15 texture { PaintedSteel_White }}
    cylinder{<-40, 20, 15>, <20, 20, 15>, 0.15 texture { PaintedSteel_White }}
    
    difference {
        union {
            torus {15, 0.15 texture { PaintedSteel_White } translate <-40, 17.5, 0> }
            torus {15, 0.15 texture { PaintedSteel_White } translate <-40, 20, 0> }
        }
        box {<-40, 10, -20>, <0, 30, 20> texture { PaintedSteel_White }}
    }

    //Railling (upper level behind bridge)
    object { LinearDuplicate(cylinder{<-10, 25, -10>, <-10, 30, -10>, 0.15 texture { PaintedSteel_White }}, 5, 10) }
    object { LinearDuplicate(cylinder{<-20, 25, -10>, <-20, 30, -10>, 0.15 texture { PaintedSteel_White }}, 5, 20) Rotate_Around_Trans(<0, 90, 0>, <0, 25, -10>) }
    object { LinearDuplicate(cylinder{<-10, 25, 10>, <-10, 30, 10>, 0.15 texture { PaintedSteel_White }}, 5, 10) }

    cylinder {<-10, 27.5, -10>, <0, 27.5, -10>, 0.15 texture { PaintedSteel_White }}
    cylinder {<0, 27.5, -10>, <0, 27.5, 10>, 0.15 texture { PaintedSteel_White }}
    cylinder {<-10, 27.5, 10>, <0, 27.5, 10>, 0.15 texture { PaintedSteel_White }}

    cylinder {<-10, 30, -10>, <0, 30, -10>, 0.15 texture { PaintedSteel_White }}
    cylinder {<0, 30, -10>, <0, 30, 10>, 0.15 texture { PaintedSteel_White }}
    cylinder {<-10, 30, 10>, <0, 30, 10>, 0.15 texture { PaintedSteel_White }}

    //Capping on railling (around bridge wings)
    cylinder {<-27, 30, -14>, <-10, 30, -14>, 0.15 texture { PaintedSteel_White }}
    cylinder {<-27, 30, 14>, <-10, 30, 14>, 0.15 texture { PaintedSteel_White }}
    
    cylinder {<-27, 30, -14>, <-27, 30, -9>, 0.15 texture { PaintedSteel_White }}
    cylinder {<-27, 30, 14>, <-27, 30, 9>, 0.15 texture { PaintedSteel_White }}
    
    cylinder {<-10, 30, -14>, <-10, 30, -10>, 0.15 texture { PaintedSteel_White }}
    cylinder {<-10, 30, 14>, <-10, 30, 10>, 0.15 texture { PaintedSteel_White }}

    //Box at base of derick
    difference {
        box {
            <19, 15, -8>, <29, 25, 8>
            texture { PaintedSteel_White }
        }
    
        box {
            <19.1, 15, -7.9>, <28.9, 24.9, 7.9>
            texture { PaintedSteel_White }
        }

        cylinder {<25, 22, -20>, <25, 22, 20>, 1 texture { PaintedSteel_White } }
    }
    
    object { Ship_Portal translate <25, 22, -8> }

    //Stack
    difference {
        union {
            cylinder {
                <3, 15, 0>, <3, 40, 0>, 2
                scale x*1.2
                
                texture { PaintedSteel_White }
            }
            
            cylinder {
                <3, 40, 0>, <3, 45, 0>, 2
                scale x*1.2
                
                texture { PaintedSteel_Red }
            }
            
            cylinder {
                <3, 45, 0>, <3, 47, 0>, 2
                scale x*1.2
                
                texture { PaintedSteel_White }
            }
        }

        cylinder {
            <3, 15, 0>, <3, 50, 0>, 1.9
            scale x*1.2
            
            texture{ MattBlack }
        }
    }
    
    //Mast
    union {
        cylinder {
            <-20, 35, 0>, <-20, 65, 0>, 0.6
            texture { PaintedSteel_Red }
        }
        
        cylinder {
            <-20, 60, -5>, <-20, 60, 5>, 0.25
            texture { PaintedSteel_Red }
        }
    }
    
    //Derick
    union {
        cylinder {
            <29, 15, -14>, <32, 50, 0>, 0.75
            texture { PaintedSteel_Red }
        }

        cylinder {
            <29, 15, 14>, <32, 50, 0>, 0.75
            texture { PaintedSteel_Red }
        }

        cylinder {
            <10, 15, 0>, <32, 50, 0>, 0.6
            texture { PaintedSteel_Red }
        }
        
        //Bracing on Berick
        cylinder {
            <31, 38, -5>, <31, 38, 5>, 0.75
            texture { PaintedSteel_Red }
        }

        cylinder {
            <31, 38, -5>, <25, 38, 0>, 0.75
            texture { PaintedSteel_Red }
        }

        cylinder {
            <31, 38, 5>, <25, 38, 0>, 0.6
            texture { PaintedSteel_Red }
        }
        
        //Boom
        cylinder {
            <29, 16, 0>, <80, 16, 0>, 0.6
            texture { PaintedSteel_Red }
        }
        
        //Lines to end of boom
        cylinder {
            <32, 49, 0>, <70, 16, 0>, 0.05
            pigment{Sienna}
        }
        cylinder {
            <32, 50, 0>, <71, 16, 0>, 0.05
            pigment{Sienna}
        }

        //Mast on top of Derick
        cylinder {
            <32, 50, 0>, <32, 65, 0>, 0.4
            texture { PaintedSteel_Red }
        }
        
        cylinder {
            <32, 60, -5>, <32, 60, 5>, 0.25
            texture { PaintedSteel_Red }
        }
    }
    
    //Lifeboats
    object { Ship_Lifeboat translate<10, 23, -10> }
    object { Ship_Lifeboat translate<10, 23, 10> }
    
    //Railes for lifeboad
    //Left
    union {
        box {
            <6, 21, -5>, <6.5, 22, -22>
            texture { PaintedSteel_White }
        }


        box {
            <13.5, 21, -5>, <14, 22, -22>
            texture { PaintedSteel_White }
        }
        
        Rotate_Around_Trans(<-10, 0, 0>, <6.5, 22, -10>)
    }
    
    box {
        <0, 21.5, -6>, <25, 22.5, -6.5>
        texture { PaintedSteel_White }
    }
    
    difference {
        box {
            <5.5, 5, -18>, <16, 19.5, -18.5>
            texture { PaintedSteel_White }
        }
        
        box {
            <6.5, 5, -20>, <15, 18.5, -10>
            texture { PaintedSteel_White }
        }
    }

    //Right
    union {
        box {
            <6, 21, 5>, <6.5, 22, 22>
            texture { PaintedSteel_White }
        }


        box {
            <13.5, 21, 5>, <14, 22, 22>
            texture { PaintedSteel_White }
        }
        
        Rotate_Around_Trans(<10, 0, 0>, <6.5, 22, 10>)
    }
    
    box {
        <0, 21.5, 6>, <25, 22.5, 6.5>
        texture { PaintedSteel_White }
    }
    
    difference {
        box {
            <5.5, 5, 18>, <16, 19.5, 18.5>
            texture { PaintedSteel_White }
        }
        
        box {
            <6.5, 5, 20>, <15, 18.5, 10>
            texture { PaintedSteel_White }
        }
    }
    
    //wires between masts
    difference {
        union {
            torus {
                200, 0.05
                
                rotate x*90
                translate <6, 258.5, -5>
                
                pigment {Sienna}
            }
        
            torus {
                200, 0.05
                
                rotate x*90
                translate <6, 258.5, 5>
                
                pigment {Sienna}
            }
        }
        
        box {
            <-2000, 0, -10>, <-20, 4000, 10>
            
            pigment {Sienna}
        }
        
        box {
            <32, 0, -10>, <2000, 4000, 10>
            
            pigment {Sienna}
        }
        
        box {
            <-2000, 100, -10>, <2000, 4000, 10>
            
            pigment {Sienna}
        }
    }
    
    cylinder {
        <6, 58.5, -5>, <6, 15, -2>, 0.05
        pigment{Sienna}
    }
    
    cylinder {
        <6, 58.5, 5>, <6, 15, 2>, 0.05
        pigment{Sienna}
    }
    
    //Flag staffs
    //Bow
    cylinder {
        <-97, 10, 0>, <-97, 30, 0>, 0.25
        texture { PaintedSteel_White }
    }
    
    //Stern
    cylinder {
        <95, 7, 0>, <95, 20, 0>, 0.25
        Rotate_Around_Trans(<0, 0, -15>, <95, 7, 0>)
        texture { PaintedSteel_White }
    }
}

//////////////////////////////////////////////////////////////////////////
// Put the whole lot together

#declare Lighthouse = union {
    object{ L_Base }
    object{ L_Tower }
    object{ L_TowerInt }
    object{ L_Platform }
    object{ L_Top }
}

object{ Lighthouse }
object{ S_Rock } 
#if(Water)
    object{ S_Sea }
#end
object{ S_Sky } 
object{ S_Bird translate<25, 0, -2> }
object { Ship rotate y*-35 translate <100, 0, 900> }
